.. :changelog:

History
-------

1.0.1 (2018-12-30)
++++++++++++++++++

* Add tests for Python 3.7
* Add tests for Django 2.1
* Remove Pipenv
* Change packaging and dependency manager to Poetry

1.0.0 (2018-02-18)
++++++++++++++++++

* First release on PyPI.
